#! /usr/bin/env bash

alias @browse=abcli_browse

alias @env=abcli_env

alias @eval=abcli_eval

alias @hr=abcli_hr

alias @cat=abcli_cat

alias @log_list=abcli_log_list

alias @open=abcli_open

alias @option=abcli_option
alias @option::int=abcli_option_int
alias @option::choice=abcli_option_choice
alias @option::subset=abcli_option_subset

alias @options=blue_options

alias @pause=abcli_pause
